@@ -12,6 +12,7 @@
 """
 __author__ = 'Asdil'
 import base64
+import pickle
 
 
 def base_encrypt(data):
@@ -45,3 +46,36 @@ def base_decrypt(data):
     decrypt_data = base64.b64decode(data)
     decrypt_data = str(decrypt_data, encoding="utf8")
     return decrypt_data
+
+
+def encode(data):
+    """encode方法用于压缩数据编程字符串
+
+    Parameters
+    ----------
+    data : object
+        任何对象
+
+    Returns
+    ----------
+    """
+    data = pickle.dumps(data)
+    data = base64.b64encode(data)
+    return data
+
+
+def decode(data):
+    """decode方法用于解压byte字符串转化为对象
+
+    Parameters
+    ----------
+    data : byte
+        byte对象
+    Returns
+    ----------
+    """
+    if type(data) is dict:
+        return data
+    data = base64.b64decode(data)
+    data = pickle.loads(data)
+    return data
\ No newline at end of file
